package args
import "k8s.io/kube-openapi/cmd/openapi-gen/args"
Index ¶
Types ¶
type Args ¶
type Args struct {
OutputDir string // must be a directory path
OutputPkg string // must be a Go import-path
OutputFile string
GoHeaderFile string
// ReportFilename is added to Args for specifying name of report file used
// by API linter. If specified, API rule violations will be printed to report file.
// Otherwise default value "-" will be used which indicates stdout.
ReportFilename string
}
func New ¶
func New() *Args
New returns default arguments for the generator. Returning the arguments instead of using default flag parsing allows registering custom arguments afterwards
func (*Args) AddFlags ¶
AddFlags add the generator flags to the flag set.
func (*Args) Validate ¶
Validate checks the given arguments.
Source Files ¶
args.go
- Version
- v0.0.0-20250628140032-d90c4fd18f59 (latest)
- Published
- Jun 28, 2025
- Platform
- linux/amd64
- Imports
- 2 packages
- Last checked
- 10 months ago –
Tools for package owners.